@@ -2,9 +2,9 @@
 //!
 //! With Output
 //! ```bash
-//! 2020-12-12 17:16:02:340877000 [INFO] <toml_log:37>:info toml simple_log
-//! 2020-12-12 17:16:02:341504000 [WARN] <toml_log:38>:warn toml simple_log
-//! 2020-12-12 17:16:02:341569000 [ERROR] <toml_log:39>:error toml simple_log
+//! 2020-12-12 17:16:02.340877000 [INFO] <toml_log:37>:info toml simple_log
+//! 2020-12-12 17:16:02.341504000 [WARN] <toml_log:38>:warn toml simple_log
+//! 2020-12-12 17:16:02.341569000 [ERROR] <toml_log:39>:error toml simple_log
 //! ```
 
 #[macro_use]
@@ -26,6 +26,7 @@ fn main() {
     size = 10
     out_kind = ["console","file"]
     roll_count = 10
+    time_format = "%H:%M:%S.%f"
     "#;
     let wrap: LogConfigWrap = toml::from_str(config).unwrap();
 
